@@ -1,3 +1,4 @@
+from worker.event.event_handler import EventHandler
 from testcase.app.drilling_efficiency_app import DrillingEfficiency
 
 
@@ -9,6 +10,5 @@ def lambda_handler(event, context):
     :return:
     """
     app = DrillingEfficiency()
-    app.load(event)
-    app.run_modules()
-    app.save_state()
+    event_handler = EventHandler(app)
+    event_handler.process(event)
