@@ -37,7 +37,7 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         self.event_type: EventType = None
 
         self.asset_id = None
-        self.event_records = None
+        self.event = None  # event records
 
         super().__init__(*args, **kwargs)
 
@@ -56,9 +56,9 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         event = self.load_event(event, max_lookback_seconds)
 
         valid_stream_collections = self.get_valid_stream_collections()
-        self.event_records = self.filter_event_for_collections(self.event_type, valid_stream_collections, event)
+        self.event = self.filter_event_for_collections(self.event_type, valid_stream_collections, event)  # event records
 
-        self.log_event(self.event_records, max_lookback_seconds)
+        self.log_event(self.event, max_lookback_seconds)  # event records
 
     def log_event(self, event: List[dict], max_lookback_seconds: int):
         self.debug(self.asset_id, "WITS input to {0} -> {1}".format(self.app_name, event))
@@ -132,7 +132,7 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         event = [record for record in event if record.get("collection") in valid_stream_collections]
         return event
 
-    def filter_event_for_duplicates(self, event):
+    def filter_event_for_duplicates(self, event) -> list:
         last_processed_timestamp = self.state.get('last_processed_timestamp') or 0
 
         # If event is a single record and greater than the last processed timestamp, return the event
@@ -188,7 +188,13 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         # First filtering original event for duplicates
         records = self.filter_event_for_duplicates(records)
 
-        first_timestamp = records[0].get('timestamp')
+        # If all record timestamps are before the last processed timestamp,
+        # the first timestamp will be the last processed timestamp from cache
+        if not records:
+            first_timestamp = self.state.get('last_processed_timestamp') or 0
+        else:
+            first_timestamp = records[0].get('timestamp')
+
         if not first_timestamp:
             return records
 
@@ -237,7 +243,7 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         return [module for module in self.get_modules() if module.enabled]
 
     def run_modules(self):
-        if not self.event_records:
+        if not self.event:  # event records
             return
 
         for module_type in self.get_active_modules():
@@ -247,11 +253,11 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
                 raise exceptions.Misconfigured("Module {0} not able to initialize for asset_id {1}".format(module_type, self.asset_id))
 
             try:
-                module.run(self.event_records)
+                module.run(self.event)  # event records
             except Exception:
                 message = f"Error in module {module_type.module_key}"
                 self.track_error(message=message)
                 raise
 
-        last_processed_timestamp = self.event_records[-1].get('timestamp')
+        last_processed_timestamp = self.event[-1].get('timestamp')  # event records
         self.state['last_processed_timestamp'] = last_processed_timestamp
