@@ -19,7 +19,7 @@ class Event(abc.ABC):
         self.records.extend(new_records)
 
     @abc.abstractmethod
-    def complete_event(self) -> None:
+    def complete_event(self, api) -> None:
         raise NotImplementedError
 
     def __len__(self):
